@@ -8,11 +8,11 @@ package IO::Async::Resolver;
 use strict;
 use warnings;
 
-our $VERSION = '0.35';
+our $VERSION = '0.36';
 
 use Socket::GetAddrInfo qw(
    :newapi getaddrinfo getnameinfo
-   AI_NUMERICHOST AI_NUMERICSERV
+   AI_NUMERICHOST
    NI_NUMERICHOST NI_NUMERICSERV
    EAI_NONAME
 );
@@ -53,12 +53,31 @@ This object is used indirectly via an C<IO::Async::Loop>:
  use IO::Async::Loop;
  my $loop = IO::Async::Loop->new();
 
- $loop->resolve( type => 'getpwuid', data => [ $< ],
-    on_resolved => 
-       sub { print "My passwd ent: " . join( "|", @_ ) . "\n" },
+ $loop->resolver->getaddrinfo(
+    host    => "www.example.com",
+    service => "http",
 
-    on_error =>
-       sub { print "Cannot look up my passwd ent - $_[0]\n" },
+    on_resolved => sub {
+       foreach my $addr ( @_ ) {
+          printf "http://www.example.com can be reached at " .
+             "socket(%d,%d,%d) + connect('%v02x')\n",
+             @{$addr}{qw( family socktype protocol addr )};
+       }
+    },
+
+    on_error => sub {
+       print "Cannot look up www.example.com - $_[-1]\n";
+    },
+ );
+
+ $loop->resolve( type => 'getpwuid', data => [ $< ],
+    on_resolved => sub {
+       print "My passwd ent: " . join( "|", @_ ) . "\n";
+    },
+
+    on_error => sub {
+       print "Cannot look up my passwd ent - $_[-1]\n";
+    },
  );
 
  $loop->loop_forever;
@@ -246,8 +265,8 @@ succeed.
 
 Specifically, if the service name is entirely numeric, and the hostname looks
 like an IPv4 or IPv6 string, a synchronous lookup will first be performed
-using the C<AI_NUMERICHOST> and C<AI_NUMERICSERV> flags. If this gives an
-C<EAI_NONAME> error, then the lookup is performed asynchronously instead.
+using the C<AI_NUMERICHOST> flag. If this gives an C<EAI_NONAME> error, then
+the lookup is performed asynchronously instead.
 
 =cut
 
@@ -263,16 +282,18 @@ sub getaddrinfo
    $args{family}   = _getfamilybyname( $args{family} )     if defined $args{family};
    $args{socktype} = _getsocktypebyname( $args{socktype} ) if defined $args{socktype};
 
-   # It's likely this will succeed with AI_NUMERICHOST|AI_NUMERICSERV if
-   #   host contains only [\d.] (IPv4) or [[:xdigit:]:] (IPv6)
-   #   service contains only \d
-   # These tests don't have to be perfect as if it fails we'll get EAI_NONAME
-   # and just try it asynchronously anyway
+   # It's likely this will succeed with AI_NUMERICHOST if host contains only
+   # [\d.] (IPv4) or [[:xdigit:]:] (IPv6)
+   # Technically we should pass AI_NUMERICSERV but not all platforms support
+   # it, but since we're checking service contains only \d we should be fine.
+
+   # These address tests don't have to be perfect as if it fails we'll get
+   # EAI_NONAME and just try it asynchronously anyway
    if( ( $host =~ m/^[\d.]+$/ or $host =~ m/^[[:xdigit:]:]$/ ) and
        $service =~ m/^\d+$/ ) {
 
        my ( $err, @results ) = _getaddrinfo( $host, $service,
-          { %args, flags => $flags | AI_NUMERICHOST|AI_NUMERICSERV }
+          { %args, flags => $flags | AI_NUMERICHOST }
        );
 
        if( !$err ) {
