@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2009 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2009-2011 -- leonerd@leonerd.org.uk
 
 package IO::Async::Timer;
 
@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use base qw( IO::Async::Notifier );
 
-our $VERSION = '0.35';
+our $VERSION = '0.36';
 
 use Carp;
 
@@ -153,7 +153,8 @@ sub start
 
 =head2 $timer->stop
 
-Stops the Timer if it is running.
+Stops the Timer if it is running. If it has not yet been added to the C<Loop>
+but there is a start pending, this will cancel it.
 
 =cut
 
@@ -161,6 +162,11 @@ sub stop
 {
    my $self = shift;
 
+   if( $self->{pending} ) {
+      delete $self->{pending};
+      return;
+   }
+
    my $loop = $self->get_loop or croak "Cannot stop a Timer that is not in a Loop";
 
    defined $self->{id} or return; # nothing to do but no error
